@@ -1,6 +1,9 @@
 """Definitions of fields."""
 
+import datetime
+
 import six
+from dateutil.parser import parse
 
 from .error import ValidationError
 
@@ -96,6 +99,18 @@ class FloatField(BaseField):
     _types = (float, int)
 
 
+class BoolField(BaseField):
+
+    """Bool field."""
+
+    _types = (bool,)
+
+    def parse_value(self, value):
+        """Cast value to `bool`."""
+        parsed = super(BoolField, self).parse_value(value)
+        return bool(parsed) if parsed is not None else None
+
+
 class ListField(BaseField):
 
     """List field."""
@@ -108,7 +123,12 @@ class ListField(BaseField):
         return self._items_types
 
     def __init__(self, items_types=None, *args, **kwargs):
-        """Init."""
+        """Init.
+
+        `ListField` is **always not required**. If you want to control number
+        of items use validators.
+
+        """
         if items_types:
             try:
                 self._items_types = tuple(items_types)
@@ -117,6 +137,7 @@ class ListField(BaseField):
         else:
             self._items_types = tuple()
         super(ListField, self).__init__(*args, **kwargs)
+        self.required = False
 
     def validate(self, name, value):
         """Validation."""
@@ -125,15 +146,18 @@ class ListField(BaseField):
         if len(self._items_types) == 0:
             return
 
-        for item in value:
-            if not isinstance(item, self._items_types):
-                raise ValidationError(
-                    'All items of "{}" must be instances '
-                    'of "{}", and not "{}".'.format(
-                        name,
-                        ', '.join([t.__name__ for t in self._items_types]),
-                        type(item).__name__
-                    ))
+        try:
+            for item in value:
+                if not isinstance(item, self._items_types):
+                    raise ValidationError(
+                        'All items of "{}" must be instances '
+                        'of "{}", and not "{}".'.format(
+                            name,
+                            ', '.join([t.__name__ for t in self._items_types]),
+                            type(item).__name__
+                        ))
+        except TypeError:
+            pass
 
     def to_struct(self, value):
         """Cast value to structure."""
@@ -208,3 +232,85 @@ class EmbeddedField(BaseField):
         embed_type = self._types[0]
 
         return embed_type(**value)
+
+
+class TimeField(StringField):
+
+    """Time field."""
+
+    _types = (datetime.time,)
+
+    def __init__(self, str_format=None, *args, **kwargs):
+        """Init.
+
+        :param str str_format: Format to cast time to (if `None` - casting to
+            ISO 8601 format).
+
+        """
+        self.str_format = str_format
+        super(TimeField, self).__init__(*args, **kwargs)
+
+    def to_struct(self, value):
+        """Cast `time` object to string."""
+        if self.str_format:
+            return value.strftime(self.str_format)
+        return value.isoformat()
+
+    def parse_value(self, value):
+        """Parse string into instance of `time`."""
+        return parse(value).timetz()
+
+
+class DateField(StringField):
+
+    """Date field."""
+
+    _types = (datetime.date,)
+    default_format = '%Y-%m-%d'
+
+    def __init__(self, str_format=None, *args, **kwargs):
+        """Init.
+
+        :param str str_format: Format to cast date to (if `None` - casting to
+            %Y-%m-%d format).
+
+        """
+        self.str_format = str_format
+        super(DateField, self).__init__(*args, **kwargs)
+
+    def to_struct(self, value):
+        """Cast `date` object to string."""
+        if self.str_format:
+            return value.strftime(self.str_format)
+        return value.strftime(self.default_format)
+
+    def parse_value(self, value):
+        """Parse string into instance of `date`."""
+        return parse(value).date()
+
+
+class DateTimeField(StringField):
+
+    """Datetime field."""
+
+    _types = (datetime.datetime,)
+
+    def __init__(self, str_format=None, *args, **kwargs):
+        """Init.
+
+        :param str str_format: Format to cast datetime to (if `None` - casting
+            to ISO 8601 format).
+
+        """
+        self.str_format = str_format
+        super(DateTimeField, self).__init__(*args, **kwargs)
+
+    def to_struct(self, value):
+        """Cast `datetime` object to string."""
+        if self.str_format:
+            return value.strftime(self.str_format)
+        return value.isoformat()
+
+    def parse_value(self, value):
+        """Parse string into instance of `datetime`."""
+        return parse(value)
